@@ -29,9 +29,9 @@
 #include <fcntl.h>
 #include <sys/time.h>
 
-
 #include "rs232.c"
 
+
 #define HEX(c) (int)(((c) < 'A') ? ((c) - '0') : ((c) - 'A') + 10)
 #define MAX_STEP_FREQ 1000
 
@@ -808,7 +808,7 @@ static void optimize_values(int axis)
 {
     if(!ahp_gt_is_detected(ahp_gt_get_current_device()))
         return;
-    double baseclock = 375000;
+    double baseclock = 1500000;
     double usteps = 62.0;
     double maxdiv = 14.0;
     devices[ahp_gt_get_current_device()].wormsteps [axis] = (int)(devices[ahp_gt_get_current_device()].steps [axis] * devices[ahp_gt_get_current_device()].worm [axis] / devices[ahp_gt_get_current_device()].motor [axis]);
@@ -841,7 +841,6 @@ static void optimize_values(int axis)
     default:
         break;
     }
-    devices[ahp_gt_get_current_device()].one_second[axis] = (1500000.0);
     devices[ahp_gt_get_current_device()].wormsteps [axis] *= (double)devices[ahp_gt_get_current_device()].multiplier [axis] / (double)devices[ahp_gt_get_current_device()].divider [axis];
     devices[ahp_gt_get_current_device()].totalsteps [axis] = (int)(devices[ahp_gt_get_current_device()].crown [axis] * devices[ahp_gt_get_current_device()].wormsteps [axis]);
 
@@ -852,6 +851,8 @@ static void optimize_values(int axis)
     devices[ahp_gt_get_current_device()].maxspeed_value [axis] = (int)fmax(devices[ahp_gt_get_current_device()].minperiod [axis], (devices[ahp_gt_get_current_device()].maxperiod [axis] / devices[ahp_gt_get_current_device()].maxspeed [axis]));
     devices[ahp_gt_get_current_device()].guide [axis] = (int)(SIDEREAL_DAY * baseclock / devices[ahp_gt_get_current_device()].totalsteps [axis]);
 
+    devices[ahp_gt_get_current_device()].one_second[axis] = (baseclock+baseclock*(sidereal_period-floor(sidereal_period))/floor(sidereal_period));
+
     double degrees = devices[ahp_gt_get_current_device()].acceleration [axis] * (double)devices[ahp_gt_get_current_device()].totalsteps [axis] / devices[ahp_gt_get_current_device()].multiplier [axis] / (M_PI * 2.0);
     devices[ahp_gt_get_current_device()].accel_steps [axis] = floor(fmin(63, pow(degrees * 2, 0.4) + 1));
     devices[ahp_gt_get_current_device()].accel_increment [axis] = (int)fmin (0xff, devices[ahp_gt_get_current_device()].guide [axis] / devices[ahp_gt_get_current_device()].accel_steps [axis]);
@@ -1043,7 +1044,6 @@ void ahp_gt_read_values(int axis)
     devices[ahp_gt_get_current_device()].address_value = (devices[ahp_gt_get_current_device()].dividers >> 9) & 0x7f;
     devices[ahp_gt_get_current_device()].rs232_polarity = devices[ahp_gt_get_current_device()].dividers & 1;
 
-    devices[ahp_gt_get_current_device()].motor [axis] = 1;
     if (devices[ahp_gt_get_current_device()].steps [axis] == 0)
         devices[ahp_gt_get_current_device()].steps [axis] = 1;
     if (devices[ahp_gt_get_current_device()].wormsteps [axis] == 0)
@@ -1055,17 +1055,19 @@ void ahp_gt_read_values(int axis)
     if (devices[ahp_gt_get_current_device()].maxspeed_value [axis] == 0)
         devices[ahp_gt_get_current_device()].maxspeed_value [axis] = 1;
     double degrees = pow(devices[ahp_gt_get_current_device()].accel_steps [axis] - 1, 2.5) / 2.0;
+    double crown = (double)devices[ahp_gt_get_current_device()].totalsteps [axis] / devices[ahp_gt_get_current_device()].wormsteps [axis];
+    double worm = (double)devices[ahp_gt_get_current_device()].wormsteps [axis] * devices[ahp_gt_get_current_device()].divider [axis] / devices[ahp_gt_get_current_device()].steps [axis] / devices[ahp_gt_get_current_device()].multiplier [axis];
+    double motor = 1.0;
     devices[ahp_gt_get_current_device()].acceleration [axis] = degrees / ((double)devices[ahp_gt_get_current_device()].totalsteps [axis] / devices[ahp_gt_get_current_device()].multiplier [axis] / (M_PI * 2.0));
-    devices[ahp_gt_get_current_device()].crown [axis] = devices[ahp_gt_get_current_device()].totalsteps [axis] / devices[ahp_gt_get_current_device()].wormsteps [axis];
-    devices[ahp_gt_get_current_device()].worm [axis] = devices[ahp_gt_get_current_device()].wormsteps [axis] * devices[ahp_gt_get_current_device()].divider [axis] / devices[ahp_gt_get_current_device()].steps [axis] / devices[ahp_gt_get_current_device()].multiplier [axis];
-    double decimals = devices[ahp_gt_get_current_device()].worm [axis] - floor(devices[ahp_gt_get_current_device()].worm [axis]);
-    decimals /= floor(devices[ahp_gt_get_current_device()].worm [axis]);
+    double decimals = worm - round(worm);
     if(decimals != 0.0) {
-        devices[ahp_gt_get_current_device()].motor [axis] /= decimals;
-        devices[ahp_gt_get_current_device()].worm [axis] /= decimals;
+        decimals /= round(motor / worm) / worm;
+        motor = 1.0 / decimals;
+        worm /= decimals;
     }
-    devices[ahp_gt_get_current_device()].motor [axis] = floor(devices[ahp_gt_get_current_device()].motor [axis]);
-    devices[ahp_gt_get_current_device()].worm [axis] = floor(devices[ahp_gt_get_current_device()].worm [axis]);
+    devices[ahp_gt_get_current_device()].crown [axis] = crown;
+    devices[ahp_gt_get_current_device()].motor [axis] = fabs(round(motor));
+    devices[ahp_gt_get_current_device()].worm [axis] = fabs(round(worm));
     double sidereal_period = SIDEREAL_DAY * devices[ahp_gt_get_current_device()].multiplier[axis] * devices[ahp_gt_get_current_device()].wormsteps[axis] / devices[ahp_gt_get_current_device()].totalsteps[axis];
     devices[ahp_gt_get_current_device()].maxspeed [axis] = sidereal_period / devices[ahp_gt_get_current_device()].maxspeed_value [axis];
 }
@@ -1864,7 +1866,7 @@ void ahp_gt_correct_tracking(int axis, double target_period, int *interrupt) {
     }
     *interrupt = 1;
     ahp_gt_stop_motion(axis, 0);
-    one_second *= initial_second;
+    one_second = initial_second - initial_second*(one_second-1.0);
     ahp_gt_set_timing(axis, one_second);
     WriteAndCheck (axis, axis * 8 + 4, ahp_gt_get_timing(axis));
     dispatch_command (ReloadVars, axis, -1);
